Documentation
¶
Overview ¶
This is the struct used for examples
Code generated by BuilderGen v0.4.0
Index ¶
- type Contact
- type Person
- type PersonBuilder
- func (b *PersonBuilder) Build() *Person
- func (b *PersonBuilder) WithEmail(email *string) *PersonBuilder
- func (b *PersonBuilder) WithID(iD int) *PersonBuilder
- func (b *PersonBuilder) WithMapVal(mapVal map[string]string) *PersonBuilder
- func (b *PersonBuilder) WithName(name string) *PersonBuilder
- func (b *PersonBuilder) WithPhoneBook(phoneBook []*Contact) *PersonBuilder
- func (b *PersonBuilder) WithT(t nested.Test) *PersonBuilder
- type UnRelated
- type UnRelatedBuilder
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type PersonBuilder ¶
type PersonBuilder struct {
ID int
Name string
Email *string
PhoneBook []*Contact
MapVal map[string]string `json:"map_val"`
T nested.Test
}
func NewPersonBuilder ¶
func NewPersonBuilder(b *Person) *PersonBuilder
func (*PersonBuilder) Build ¶
func (b *PersonBuilder) Build() *Person
func (*PersonBuilder) WithEmail ¶
func (b *PersonBuilder) WithEmail(email *string) *PersonBuilder
func (*PersonBuilder) WithID ¶
func (b *PersonBuilder) WithID(iD int) *PersonBuilder
func (*PersonBuilder) WithMapVal ¶
func (b *PersonBuilder) WithMapVal(mapVal map[string]string) *PersonBuilder
func (*PersonBuilder) WithName ¶
func (b *PersonBuilder) WithName(name string) *PersonBuilder
func (*PersonBuilder) WithPhoneBook ¶
func (b *PersonBuilder) WithPhoneBook(phoneBook []*Contact) *PersonBuilder
func (*PersonBuilder) WithT ¶
func (b *PersonBuilder) WithT(t nested.Test) *PersonBuilder
type UnRelated ¶ added in v0.0.5
type UnRelated struct {
// contains filtered or unexported fields
}
type UnRelatedBuilder ¶ added in v0.3.0
type UnRelatedBuilder struct {
// contains filtered or unexported fields
}
func NewUnRelatedBuilder ¶ added in v0.3.0
func NewUnRelatedBuilder(b *UnRelated) *UnRelatedBuilder
func (*UnRelatedBuilder) Build ¶ added in v0.3.0
func (b *UnRelatedBuilder) Build() *UnRelated
func (*UnRelatedBuilder) WithimportOpts ¶ added in v0.3.0
func (b *UnRelatedBuilder) WithimportOpts(importOpts *imports.Options) *UnRelatedBuilder
func (*UnRelatedBuilder) WithotherOpts ¶ added in v0.3.0
func (b *UnRelatedBuilder) WithotherOpts(otherOpts *os.FileMode) *UnRelatedBuilder
Directories
¶
| Path | Synopsis |
|---|---|
|
This is the code used to benchmark the performance of BuilderGen
|
This is the code used to benchmark the performance of BuilderGen |
|
A nested struct in a different package
|
A nested struct in a different package |
|
Code generated by BuilderGen v0.4.0
|
Code generated by BuilderGen v0.4.0 |
Click to show internal directories.
Click to hide internal directories.